@@ -68,6 +68,8 @@ class TPSTransition(Transition):
 
     @classmethod
     def from_dict(cls, dct):
+        if 'name' not in dct:
+            dct['name'] = None
         mytrans = TPSTransition(dct['stateA'], dct['stateB'], dct['name'])
         mytrans.ensembles = dct['ensembles']
         return mytrans
@@ -500,6 +502,8 @@ class TISTransition(Transition):
 
     @classmethod
     def from_dict(cls, dct):
+        if 'name' not in dct:
+            dct['name'] = None
         mytrans = TISTransition(
             stateA=dct['stateA'],
             stateB=dct['stateB'],
